@@ -15,9 +15,7 @@ main = void $ displayConsoleRegions $ do
 	ir <- infoRegion
 	cr <- clockRegion
 	rr <- rulerRegion
-	growingDots
-	runBash
-	growingDots
+	growingDots `concurrently` runBash
 	mapM_ closeConsoleRegion [ir, cr]
 
 titleRegion :: IO ConsoleRegion
@@ -83,6 +81,8 @@ growingDots = withConsoleRegion Linear $ \r -> do
 
 runBash :: IO ()
 runBash = do
+	-- Wait for growingDots to display some.
+	threadDelay 1000000
 	-- Temporarily clear whatever console regions are open.
 	rs <- waitDisplayChange $ swapTMVar regionList []
 	putStrLn "We interrupt this demo to run a shell prompt. exit to continue!"
